@@ -7,4 +7,8 @@ impl LineJumpMode {
     pub fn new() -> LineJumpMode {
         LineJumpMode::default()
     }
+
+    pub fn reset(&mut self) {
+        self.input = String::new();
+    }
 }
