@@ -1,8 +1,8 @@
 use crate::errors::*;
-use scribe::Workspace;
-use scribe::buffer::Position;
 use crate::models::application::modes::LineJumpMode;
 use crate::view::{Colors, CursorType, StatusLineData, Style, View};
+use scribe::buffer::Position;
+use scribe::Workspace;
 
 pub fn display(workspace: &mut Workspace, mode: &LineJumpMode, view: &mut View) -> Result<()> {
     let mut presenter = view.build_presenter()?;
@@ -13,13 +13,11 @@ pub fn display(workspace: &mut Workspace, mode: &LineJumpMode, view: &mut View)
     // Draw the status line as an input prompt.
     let input_prompt = format!("Go to line: {}", mode.input);
     let input_prompt_len = input_prompt.len();
-    presenter.print_status_line(&[
-        StatusLineData {
-            content: input_prompt,
-            style: Style::Default,
-            colors: Colors::Default,
-        }
-    ]);
+    presenter.print_status_line(&[StatusLineData {
+        content: input_prompt,
+        style: Style::Default,
+        colors: Colors::Default,
+    }]);
 
     // Move the cursor to the end of the search query input.
     let cursor_line = presenter.height() - 1;
