@@ -1,9 +1,9 @@
 use crate::errors::*;
 use crate::models::application::modes::SelectMode;
-use scribe::Workspace;
-use scribe::buffer::Range;
 use crate::presenters::current_buffer_status_line_data;
 use crate::view::{Colors, CursorType, StatusLineData, Style, View};
+use scribe::buffer::Range;
+use scribe::Workspace;
 
 pub fn display(workspace: &mut Workspace, mode: &SelectMode, view: &mut View) -> Result<()> {
     let mut presenter = view.build_presenter()?;
@@ -13,7 +13,13 @@ pub fn display(workspace: &mut Workspace, mode: &SelectMode, view: &mut View) ->
     let data = buf.data();
 
     // Draw the visible set of tokens to the terminal.
-    presenter.print_buffer(buf, &data, &workspace.syntax_set, Some(&[selected_range]), None)?;
+    presenter.print_buffer(
+        buf,
+        &data,
+        &workspace.syntax_set,
+        Some(&[selected_range]),
+        None,
+    )?;
 
     presenter.print_status_line(&[
         StatusLineData {
@@ -21,7 +27,7 @@ pub fn display(workspace: &mut Workspace, mode: &SelectMode, view: &mut View) ->
             style: Style::Default,
             colors: Colors::SelectMode,
         },
-        buffer_status
+        buffer_status,
     ]);
 
     // Show a vertical bar to allow unambiguous/precise selection.
